@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2000-2003 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 2000-2005 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
@@ -25,6 +25,9 @@
 #define _SCPRIVATE_H
 
 #include <sys/cdefs.h>
+#include <sys/socket.h>
+#include <sys/syslog.h>
+#include <mach/message.h>
 
 #include <CoreFoundation/CoreFoundation.h>
 
@@ -33,6 +36,12 @@
 #include <SystemConfiguration/SCDynamicStoreSetSpecificPrivate.h>
 
 #include <SystemConfiguration/SCPreferencesPrivate.h>
+#include <SystemConfiguration/SCPreferencesGetSpecificPrivate.h>
+#include <SystemConfiguration/SCPreferencesSetSpecificPrivate.h>
+
+/*!
+	@header SCPrivate
+ */
 
 /* framework variables */
 extern Boolean	_sc_debug;	/* TRUE if debugging enabled */
@@ -43,19 +52,19 @@ __BEGIN_DECLS
 
 /*!
 	@function _SCErrorSet
-	@discussion Returns a last SystemConfiguration.framework API error code.
-	@result The last error encountered.
+	@discussion Sets the last SystemConfiguration.framework API error code.
+	@param error The error encountered.
  */
 void		_SCErrorSet			(int			error);
 
-/*
+/*!
 	@function _SCSerialize
 	@discussion Serialize a CFPropertyList object for passing
 		to/from configd.
 	@param obj CFPropertyList object to serialize
 	@param xml A pointer to a CFDataRef, NULL if data should be
 		vm_allocated.
-	@param data A pointer to the newly allocated/serialized data
+	@param dataRef A pointer to the newly allocated/serialized data
 	@param dataLen A pointer to the length in bytes of the newly
 		allocated/serialized data
  */
@@ -64,14 +73,14 @@ Boolean		_SCSerialize			(CFPropertyListRef	obj,
 						 void			**dataRef,
 						 CFIndex		*dataLen);
 
-/*
+/*!
 	@function _SCUnserialize
 	@discussion Unserialize a stream of bytes passed from/to configd
 		into a CFPropertyList object.
 	@param obj A pointer to memory that will be filled with the CFPropertyList
 		associated with the stream of bytes.
 	@param xml CFDataRef with the serialized data
-	@param data A pointer to the serialized data
+	@param dataRef A pointer to the serialized data
 	@param dataLen A pointer to the length of the serialized data
 
 	Specify either "xml" or "data/dataLen".
@@ -81,14 +90,14 @@ Boolean		_SCUnserialize			(CFPropertyListRef	*obj,
 						 void			*dataRef,
 						 CFIndex		dataLen);
 
-/*
+/*!
 	@function _SCSerializeString
 	@discussion Serialize a CFString object for passing
 		to/from configd.
 	@param str CFString key to serialize
 	@param data A pointer to a CFDataRef, NULL if storage should be
 		vm_allocated.
-	@param data A pointer to the newly allocated/serialized data
+	@param dataRef A pointer to the newly allocated/serialized data
 	@param dataLen A pointer to the length in bytes of the newly
 		allocated/serialized data
  */
@@ -97,14 +106,14 @@ Boolean		_SCSerializeString		(CFStringRef		str,
 						 void			**dataRef,
 						 CFIndex		*dataLen);
 
-/*
+/*!
 	@function _SCUnserializeString
 	@discussion Unserialize a stream of bytes passed from/to configd
 		into a CFString object.
 	@param str A pointer to memory that will be filled with the CFPropertyList
 		associated with the stream of bytes.
 	@param utf8 CFDataRef with the serialized data
-	@param data A pointer to the serialized data
+	@param dataRef A pointer to the serialized data
 	@param dataLen A pointer to the length of the serialized data
 
 	Specify either "utf8" or "data/dataLen".
@@ -114,12 +123,12 @@ Boolean		_SCUnserializeString		(CFStringRef		*str,
 						 void			*dataRef,
 						 CFIndex		dataLen);
 
-/*
+/*!
 	@function _SCSerializeData
 	@discussion Serialize a CFData object for passing
 		to/from configd.
 	@param data CFData key to serialize
-	@param data A pointer to the newly allocated/serialized data
+	@param dataRef A pointer to the newly allocated/serialized data
 	@param dataLen A pointer to the length in bytes of the newly
 		allocated/serialized data
  */
@@ -127,20 +136,20 @@ Boolean		_SCSerializeData		(CFDataRef		data,
 						 void			**dataRef,
 						 CFIndex		*dataLen);
 
-/*
+/*!
 	@function _SCUnserializeData
 	@discussion Unserialize a stream of bytes passed from/to configd
 		into a CFData object.
 	@param data A pointer to memory that will be filled with the CFPropertyList
 		associated with the stream of bytes.
-	@param data A pointer to the serialized data
+	@param dataRef A pointer to the serialized data
 	@param dataLen A pointer to the length of the serialized data
  */
 Boolean		_SCUnserializeData		(CFDataRef		*data,
 						 void			*dataRef,
 						 CFIndex		dataLen);
 
-/*
+/*!
 	@function _SCSerializeMultiple
 	@discussion Convert a CFDictionary containing a set of CFPropertlyList
 		values into a CFDictionary containing a set of serialized CFData
@@ -150,7 +159,7 @@ Boolean		_SCUnserializeData		(CFDataRef		*data,
  */
 CFDictionaryRef	_SCSerializeMultiple		(CFDictionaryRef	dict);
 
-/*
+/*!
 	@function _SCUnserializeMultiple
 	@discussion Convert a CFDictionary containing a set of CFData
 		values into a CFDictionary containing a set of serialized
@@ -160,11 +169,11 @@ CFDictionaryRef	_SCSerializeMultiple		(CFDictionaryRef	dict);
  */
 CFDictionaryRef	_SCUnserializeMultiple		(CFDictionaryRef	dict);
 
-/*
+/*!
 	@function _SC_cfstring_to_cstring
 	@discussion Extracts a C-string from a CFString.
 	@param cfstr The CFString to extract the data from.
-	@param buf A user provided buffer of the specefied length.  If NULL,
+	@param buf A user provided buffer of the specified length.  If NULL,
 		a new buffer will be allocated to contain the C-string.  It
 		is the responsiblity of the caller to free an allocated
 		buffer.
@@ -179,7 +188,18 @@ char *		_SC_cfstring_to_cstring		(CFStringRef		cfstr,
 						 int			bufLen,
 						 CFStringEncoding	encoding);
 
-/*
+/*!
+ *      @function _SC_sockaddr_to_string
+ *      @discussion Formats a "struct sockaddr" for reporting
+ *      @param address The address to format
+ *	@param buf A user provided buffer of the specified length.
+ *	@param bufLen The size of the user provided buffer.
+ */
+void		_SC_sockaddr_to_string		(const struct sockaddr  *address,
+						 char			*buf,
+						 size_t			bufLen);
+
+/*!
 	@function SCLog
 	@discussion Conditionally issue a log message.
 	@param condition A boolean value indicating if the message should be logged
@@ -193,7 +213,7 @@ void		SCLog				(Boolean		condition,
 						 CFStringRef		formatString,
 						 ...);
 
-/*
+/*!
 	@function SCPrint
 	@discussion Conditionally issue a debug message.
 	@param condition A boolean value indicating if the message should be written
@@ -207,7 +227,7 @@ void		SCPrint				(Boolean		condition,
 						 CFStringRef		formatString,
 						 ...);
 
-/*
+/*!
 	@function SCTrace
 	@discussion Conditionally issue a debug message with a time stamp.
 	@param condition A boolean value indicating if the message should be written
@@ -221,6 +241,33 @@ void		SCTrace				(Boolean		condition,
 						 CFStringRef		formatString,
 						 ...);
 
+/*
+ * object / CFRunLoop  management
+ */
+void
+_SC_signalRunLoop				(CFTypeRef		obj,
+						 CFRunLoopSourceRef     rls,
+						 CFArrayRef		rlList);
+
+Boolean
+_SC_isScheduled					(CFTypeRef		obj,
+						 CFRunLoopRef		runLoop,
+						 CFStringRef		runLoopMode,
+						 CFMutableArrayRef      rlList);
+
+void
+_SC_schedule					(CFTypeRef		obj,
+						 CFRunLoopRef		runLoop,
+						 CFStringRef		runLoopMode,
+						 CFMutableArrayRef      rlList);
+
+Boolean
+_SC_unschedule					(CFTypeRef		obj,
+						 CFRunLoopRef		runLoop,
+						 CFStringRef		runLoopMode,
+						 CFMutableArrayRef      rlList,
+						 Boolean		all);
+
 __END_DECLS
 
 #endif	/* _SCPRIVATE_H */
